import * as monaco from "monaco-editor";

export function redoChange(editor: monaco.editor.IStandaloneCodeEditor) {
  editor.trigger("redo", "redo", null);
}

export function undoChange(editor: monaco.editor.IStandaloneCodeEditor) {
  editor.trigger("undo", "undo", null);
}

export function formatCode(editor: monaco.editor.IStandaloneCodeEditor) {
  editor.trigger("format", "editor.action.formatDocument", null);
}

export function downloadCode(editor: monaco.editor.IStandaloneCodeEditor) {
  const model = editor.getModel();
  if (model) {
    const code = model.getValue();
    const blob = new Blob([code], { type: "text/plain" });
    const url = URL.createObjectURL(blob);
    const a = document.createElement("a");
    a.href = url;
    const fileName = model.uri.path.split("/").pop()?.replace(/_/g, "");
    a.download = fileName || "code.txt";
    document.body.appendChild(a);
    a.click();
    document.body.removeChild(a);
    URL.revokeObjectURL(url);
  }
}

export function copyCode(editor: monaco.editor.IStandaloneCodeEditor) {
  const model = editor.getModel();
  if (model) {
    navigator.clipboard.writeText(model.getValue());
  }
}

export function moveCursorToEnd(editor: monaco.editor.IStandaloneCodeEditor) {
  const model = editor.getModel();
  if (model) {
    const position = model.getPositionAt(model.getValueLength());
    editor.setPosition(position);
    editor.focus();
  }
}
